==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Bedaŭras</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Neeblas ŝargi antaŭan ludon. Nova ludo komenciĝos.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 pasinta</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 paŝoj faritaj</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 de %2 celoj restintaj</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukceso</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Paŭzinte</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Majuskliga Klavo</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Stirklavo</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta-klavo</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt-klavo</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super-klavo</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Vindoza-klavo</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komandklavo</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Stirilo</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opcio-klavo</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Elekti lingvon de la aplikaĵo:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingvo de la Sistemo&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Noto</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bonvolu relanĉi tiun ĉi aplikaĵon por la lingva ŝanĝo efikiĝi.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nova Ludo</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Ĉaso kaj Mortigo</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Rikura Malavancanto</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pilo</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pilo 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pilo 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pilo 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pilo 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Celoj:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Grando:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Ĉaso kaj Mortigo</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Rikura Malavanco</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pilo</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pilo 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pilo 34</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pilo 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pilo 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Poentaroj de CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Poentaro</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Paŝoj</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grando</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gratulon!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Via poentaro estas inter la dek plej.
Bonvolu enigi vian nomon:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Ludo</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Montri, kie vi estis</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Montri nombron da paŝoj faritaj</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Montri pasintan tempon</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Glata movado</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Stiriloj</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Moviĝi Supren:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Moviĝi Suben:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Moviĝi Maldekstren:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Moviĝi Dekstren:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Baskuligi Flagon:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Etosoj</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Elekti Etosdosieron</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Bedaŭras</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Neeblas krei datendosierujon.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Neeblas kopii etosdosieron.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Forigi la elektitan etoson?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Neeblas forigi la elektitan etoson.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vido</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Pri</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Pri &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Ludo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pa&amp;ŭzi</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Konsileto</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Ple&amp;j Altaj Poentaroj</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ĉesi</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zom&amp;i</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Mal&amp;zomi</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Ling&amp;vo de la Aplikaĵo...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Pre&amp;feroj</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Pri</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Desupra labirintludo</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Kopirajto &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Eldonita per la &lt;a href=%1&gt;GPL 3&lt;/a&gt; permesilo</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Bildsimboloj estas de la &lt;a href=%1&gt;Oxygen&lt;/a&gt; bildsimbola etoso</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Uzata per la &lt;a href=%1&gt;LGPL 3&lt;/a&gt; permesilo</translation>
    </message>
</context>
</TS>

==> cutemaze_1.3.0.orig.tar.gz: cutemaze-1.3.0/translations/cutemaze_eo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Bedaŭras</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Neeblas ŝargi antaŭan ludon. Nova ludo komenciĝos.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 pasinta</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 paŝoj faritaj</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 de %2 celoj restintaj</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukceso</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Paŭzinte</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Majuskliga Klavo</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Stirklavo</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta-klavo</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt-klavo</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super-klavo</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Vindoza-klavo</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komandklavo</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Stirilo</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opcio-klavo</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Elekti lingvon de la aplikaĵo:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingvo de la Sistemo&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Noto</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bonvolu relanĉi tiun ĉi aplikaĵon por la lingva ŝanĝo efikiĝi.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nova Ludo</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Ĉaso kaj Mortigo</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Rikura Malavancanto</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pilo</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Pilo 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Pilo 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Pilo 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Pilo 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritmo:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Celoj:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Grando:</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Poentaro</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Paŝoj</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grando</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gratulon!</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Ludo</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Montri, kie vi estis</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Montri nombron da paŝoj faritaj</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Montri pasintan tempon</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Glata movado</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Stiriloj</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Moviĝi Supren:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Moviĝi Suben:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Moviĝi Maldekstren:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Moviĝi Dekstren:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Baskuligi Flagon:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Etosoj</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Elekti Etosdosieron</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Bedaŭras</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Neeblas krei datendosierujon.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Neeblas kopii etosdosieron.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Forigi la elektitan etoson?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Neeblas forigi la elektitan etoson.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vido</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Pri</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Pri &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Ludo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nova</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pa&amp;ŭzi</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Konsileto</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>Ple&amp;j Altaj Poentaroj</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ĉesi</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zom&amp;i</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Mal&amp;zomi</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Ling&amp;vo de la Aplikaĵo...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Pre&amp;feroj</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Pri</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Desupra labirintludo</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Kopirajto &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Eldonita per la &lt;a href=%1&gt;GPL 3&lt;/a&gt; permesilo</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Bildsimboloj estas de la &lt;a href=%1&gt;Oxygen&lt;/a&gt; bildsimbola etoso</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Uzata per la &lt;a href=%1&gt;LGPL 3&lt;/a&gt; permesilo</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
